@@ -4,17 +4,20 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef NOTIFY_H
-#define NOTIFY_H
+#pragma once
 
 #include <QObject>
 #include <QStringList>
 
 #include <BluezQt/PendingCall>
 
+#include <qqmlregistration.h>
+
 class Notify : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     explicit Notify(QObject *parent = nullptr);
@@ -22,5 +25,3 @@ public:
 public Q_SLOTS:
     void connectionFailed(const QString &title, const QString &text);
 };
-
-#endif // NOTIFY_H
